# -*- coding: utf-8 -*-
from datetime import timedelta
from time import timezone
from github import Github
from actor import actor
from event import event


def get(user,email,count=10):
    g = Github(user, email)
    result=[]
    i=0
    for e in g.get_user(user).get_events():
        a=e.actor
        e=event(created_at=e.created_at+timedelta(seconds=-timezone),
            actor=actor(login=a.login,
                avatar_url=a.avatar_url,
                url=a.url,
                id=a.id,
                email=a.email
            ),
            type=e.type,
            public=e.public,
            payload=e.payload,
            repo=e.repo
        )
        result.append(e)
        i+=1
        if i==count:
            return result
    return result